@@ -1,5 +1,5 @@
 package IO::Pager;
-our $VERSION = 0.20;
+our $VERSION = 0.24;
 
 use 5.008; #At least, for decent perlio, and other modernisms
 use strict;
@@ -8,6 +8,9 @@ use Env qw( PAGER );
 use File::Spec;
 use Symbol;
 
+use overload '+' => "PID", bool=> "PID";
+
+
 sub find_pager {
   # Return the name (or path) of a pager that IO::Pager can use
   my $io_pager;
@@ -125,8 +128,8 @@ sub TIEHANDLE {
   }
   return bless {
                 'real_fh' => $real_fh,
-                'tied_fh' => $tied_fh,
-                'child'   => $child
+                'child'   => $child,
+		'pager'   => $PAGER,
                }, $class;
 }
 
@@ -142,7 +145,6 @@ sub PRINT {
   CORE::print {$self->{real_fh}} @args or die "Could not print to PAGER: $!\n";
 }
 
-
 sub PRINTF {
   my ($self, $format, @args) = @_;
   $self->PRINT(sprintf($format, @args));
@@ -154,24 +156,29 @@ sub WRITE {
 }
 
 
-sub UNTIE {
-  my ($self) = @_;
-  CORE::close($self->{real_fh});
-}
-
-
-sub CLOSE {
-  my ($self) = @_;
-  untie *{$self->{tied_fh}};
-}
-
-
 sub TELL {
   #Buffered classes provide their own, and others may use this in another way
   return undef;
 }
 
-foreach my $method ( qw(BINMODE CLOSE PRINT PRINTF TELL WRITE) ){
+
+sub CLOSE {
+  my ($self) = @_;
+  CORE::close($self->{real_fh});
+}
+
+*DESTROY = \&CLOSE;
+
+
+#Non-IO methods
+sub PID{
+  my ($self) = @_;
+  return $self->{child};
+}
+
+
+#Provide lowercase aliases for accessors
+foreach my $method ( qw(BINMODE CLOSE PRINT PRINTF TELL WRITE PID) ){
   no strict 'refs';
   *{lc($method)} = \&{$method};
 }
@@ -205,7 +212,6 @@ IO::Pager - Select a pager and pipe text to it if destination is a TTY
     HEREDOC
 
     # $token passes out of scope and filehandle is automagically closed
-    # NOT YET IMPLEMENTED XXX
   }
 
   {
@@ -245,8 +251,7 @@ Instantiate a new IO::Pager, which will paginate output sent to
 FILEHANDLE if interacting with a TTY.
 
 Save the return value to check for errors, use as an object,
-and (NOT YET IMPLEMENTED) implicitly close the handle when
-the variable passes out of scope.
+or for implict close of OO handles when the variable passes out of scope.
 
 =over
 
@@ -268,15 +273,40 @@ Returns false and sets I<$!> on failure, same as perl's C<open>.
 
 =back
 
+=head2 PID
+
+Call this method on the token returned by C<open> to get the process
+identifier for the child process i.e; pager; if you need to perform
+some long term process management e.g; perl's C<waitpid>
+
+You can also access the PID by numifying the instantiation token like so:
+
+  my $child = $token+0;
+
 =head2 close( FILEHANDLE )
 
 Explicitly close the filehandle, this stops any redirection of output
 on FILEHANDLE that may have been warranted.
 
-Normally you'd just wait for the object to pass out of scope. NOT YET IMPLEMENTED
-
 I<This does not default to the current filehandle>.
 
+Alternatively, you may rely upon the implicit close of lexical handles
+as they pass out of scope e.g;
+
+  {
+     IO::Pager::open local *RIBBIT;
+     print RIBBIT "No toad sexing allowed";
+     ...
+  }
+  #The filehandle is closed to additional output
+
+  {
+     my $token = new IO::Pager::Buffered;
+     $token->print("I like trains");
+     ...
+  }
+  #The string "I like trains" is flushed to the pager, and the handle closed
+
 =head2 binmode( FILEHANDLE )
 
 Used to set the I/O layer a.k.a. discipline of a filehandle,
